@@ -17,5 +17,3 @@ class StyleText:
 class Debugger:
     def __call__(self, textOutput: Union[str, StyleText], *args, sep=' ', end='\n'): ...
 
-    @staticmethod
-    def AllCountActiveInstance() -> List[str]: ...
